# Testing_pypi
Testing

## How to use this

```python
from oneNeuron.perceptron import Perceptron

## get X and y and then use below commands
model = Perceptron(eta=eta, epochs=epochs)
model.fit(X, y)
```

[Python Official Docs](https://packaging.python.org/tutorials/packaging-projects/)

[Github docs](https://docs.github.com/en/actions/automating-builds-and-tests/building-and-testing-python#publishing-to-package-registries)

## created pyhton package for testing purpose only
[pypi.org link](https://pypi.org/project/Testing-pypi-nik-vaibhav18/0.0.1/)
